@@ -1113,6 +1113,21 @@ class Activity(Model):
                 self.event.update(num_comments=F('num_comments') + 1)
 
 
+class GroupSeen(Model):
+    """
+    Track when a group is last seen by a user.
+    """
+    project = models.ForeignKey(Project)
+    group = models.ForeignKey(Group)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, db_index=False)
+    last_seen = models.DateTimeField(default=timezone.now)
+
+    class Meta:
+        unique_together = (('user', 'group'),)
+
+    __repr__ = sane_repr('project_id', 'group_id', 'user_id', 'last_seen')
+
+
 class Alert(Model):
     project = models.ForeignKey(Project)
     group = models.ForeignKey(Group, null=True)
@@ -1210,12 +1225,18 @@ def create_default_project(created_models, verbosity=2, **kwargs):
         user = None
 
     project = Project.objects.create(
-        id=settings.SENTRY_PROJECT,
         public=False,
         name='Sentry (Internal)',
         slug='sentry',
         owner=user,
     )
+    # HACK: manually update the ID after insert due to Postgres
+    # sequence issues. Seriously, fuck everything about this.
+    # TODO(dcramer): find a better solution
+    if project.id != settings.SENTRY_PROJECT:
+        project.key_set.all().delete()
+        project.update(id=settings.SENTRY_PROJECT)
+        create_team_and_keys_for_project(project, created=True)
 
     if verbosity > 0:
         print 'Created internal Sentry project (slug=%s, id=%s)' % (project.slug, project.id)
